#
# spec file for package python-txtorcon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-txtorcon
Version:        24.8.0
Release:        1.2
Summary:        Twisted-based asynchronous Tor control protocol implementation
License:        MIT
URL:            https://txtorcon.readthedocs.org
Source:         https://files.pythonhosted.org/packages/source/t/txtorcon/txtorcon-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 36.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Automat
Requires:       python-Twisted-tls >= 15.5.0
Requires:       python-cryptography
Requires:       python-zope.interface >= 3.6.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  lsof
BuildRequires:  %{python_module Automat}
BuildRequires:  %{python_module Twisted-tls >= 15.5.0}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module zope.interface >= 3.6.1}
%python_subpackages

%description
Twisted-based asynchronous Tor control protocol implementation. Includes
unit-tests, examples, state-tracking code and configuration abstraction.

%prep
%autosetup -p1 -n txtorcon-%{version}

sed -i '/data_files/,/\]\,/s/^/#/' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
# remove the tests from distribution
%python_expand rm -rf %{buildroot}%{$python_sitelib}/test/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# looks more like integration tests
# Async tests don't work with pytest gh#crossbario/autobahn-python#1235
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -m twisted.trial test
}

%files %{python_files}
%license LICENSE docs/*.rst
%{python_sitelib}/txtorcon
%{python_sitelib}/txtorcon-%{version}.dist-info
%{python_sitelib}/twisted/plugins/*

%changelog
* Mon Sep 23 2024 Dirk Müller <dmueller@suse.com>
- update to 24.8.0:
  * Fix (test) issues with Twisted 24.7.0
  * Remove usage of "six"
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 23.11.0:
  * Fix test-failures on Python 3.12
  * Particular GETINFO hanging
  (ultra-long lines over 16KiB caused problems in the protocol)
  * Use built-in `mock` only
  * Remove `incremental`
* Tue Sep 19 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 23.5.0
  * Fix a bug with CONTROLLER_WAIT events
  * drop python2 support
  * Added support for Python 3.11.
  * No more ipaddress dependency
* Tue Jun 21 2022 Ben Greiner <code@bnavigator.de>
- Actually requires twisted[tls]: python-Twisted-tls
* Wed Apr 20 2022 pgajdos@suse.com
- version update to 22.0.0
  * Use GitHub Action for CI (instead of Travis)
  * fix coveralls uploading of coverage
- do not require python-mock for build
* Tue Aug 31 2021 Matej Cepl <mcepl@suse.com>
- Update to 21.1.0:
  - This fixes some incorrectly-skipped tests in 21.0.0
  * Fix some incorrect unit-test skipping logic gh#meejah/txtorcon#354
    and gh#meejah/txtorcon#352
  * Fix broken tests revealed by previous fixes gh#meejah/txtorcon#356
  * fix Python 3.x+ bug with TorInfo and .__class__ access
    (gh#meejah/txtorcon#350)
- Patch 362-skip-failing-tests.patch can be removed again.
* Tue Aug 31 2021 Matej Cepl <mcepl@suse.com>
- Add 362-skip-failing-tests.patch to skip failing tests
  (gh#meejah/txtorcon#362).
* Sat May  1 2021 Matej Cepl <mcepl@suse.com>
- Async tests don't work with pytest. Use python -m twisted.trial
  instead.
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build wihtout python2
* Mon Apr  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 20.0.0
  * Use real GeoIP database or nothing (https://github.com/meejah/txtorcon/issues/250)
  * Change abstract base classes import in preperation for Python 3.8 (thanks @glowatsk)
  * Python 3.4 is no longer supported
  * Python 2 is deprecated; all new code should be Python 3. Support
  for Python 2 will be removed in a future release.
* Mon Dec 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Drop GeoIP dependency. The geoip interface is no longer valid and
  this package was not portedto GeoIP2. The test has already been
  disarmed a while back.
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 19.1.0:
  * TorControlProtocol.on_disconnect is deprecated in favour of
    TorControlProtocol.when_disconnected
  * introduce non_anonymous_mode= kwarg in txtorcon.launch()
    enabling Tor options making Onion Services non-anonymous for the
    server (but they use a single hop instead of three to the
    Introduction Point so they're slightly faster).
  * add an API to listen to individual circuit and stream events
    (without subclassing anything). Can be used as decorators too.
    See e.g. TorState.on_circuit_new()
- Drop merged patch:
  * python-txtorcon-methods-are-bytes.patch
* Tue Jul 30 2019 pgajdos@suse.com
- fix build
- added patches
  https://github.com/meejah/txtorcon/commit/5d7ebea5086f361efe7f14aea58e512a04b401f3
  + python-txtorcon-methods-are-bytes.patch
* Mon Jun 17 2019 pgajdos@suse.com
- version update to 19.0.0
  * many upstream changes, see releases.rst
- run testsuite
- package documentation
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Apr 23 2018 tchvatal@suse.com
- Remove test directory from sitelib
* Fri Mar  2 2018 avvissu@yandex.by
- Initial package
